==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/gods/dialogs_de.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Ich habe die Vermutung, dass wir gerade etwas Schreckliches entdecken.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Ich hab`s immer gewusst: Die Götter müssen verrückt sein.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Gott ist verrückt und die ganze Welt ist sein Spielzeug.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Ich denke, du hast Recht.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Ich fürchte, du hast Recht.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Ja, es ist schockierend.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("Was können wir dagegen tun?")


dialogId("lod-v-internovat", "font_big", "We can`t leave it this way. We must incarcerate them.")
dialogStr("Wir können es nicht so lassen. Wir müssen sie einlochen.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Was müssen wir?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Sie ins Irren... ich meine in die Haftanstalt der FDTO stecken.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Du hast Recht. Sollen wir beide nehmen?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Natürlich. Wenn wir einen hierlassen, fällt ihm vielleicht eine verrückte Idee ein. Er könnte zum Beispiel anfangen, Golf zu spielen.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Wohl kaum mit diesem Schläger. Ich denke, wir werden froh sein, wenn wir einen rausbekommen. Der andere wird dann harmlos sein.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Gut. Und welchen?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("Den Gelben.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("Den Blauen.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Diesen Gelben.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Diesen Blauen.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Das überlassen wir dem Spieler.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Das sollten wir dem Spieler überlassen.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Schau dir den Schläger an: etwas schreckliches ist mit ihm passiert.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Ein rosa Monster hat wahrscheinlich an ihm gesaugt.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Mutter hatte Recht. Krankhafter Spieltrieb ist die Wurzel allen Übels.")


dialogId("lod-m-palka", "font_small", "That`s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("Das ist wahr. Es wäre viel leichter, wenn der Tischtennisschläger irgendwo anders wäre.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Hast du übrigens bemerkt, dass der echte Golfball in der Ecke oben links und das Ding in der Ecke unten rechts der Kricktball ist?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Ist das ein verstecktes Zeichen?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Wer weiß.")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Ich habe gedacht, da oben ist ein Tennisball.")


dialogId("lod-v-rozliseni", "font_big", "It`s hard to say with this screen resolution.")
dialogStr("Schwierig zu sagen, bei dieser Bildschirmauflösung.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Diesmal ist unser Ziel, einen der Götter herauszubekommen.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Daneben!")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Daneben!")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Daneben!")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Daneben!")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Daneben!")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("Treffer!")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("Treffer!")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("Treffer!")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("Treffer!")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Versenkt!")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Versenkt!")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Versenkt!")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("Ich habe gewonnen, du Muttersöhnchen")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Ich fange an!")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Gut!")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Wollen wir noch eins spielen?")


dialogId("b1-nepodvadim", "font_yellow", "I don`t cheat.")
dialogStr("Ich schummle nicht!")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("Es war wahrscheinlich ein Fehler...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Daneben!")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Daneben!")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Daneben!")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Daneben!")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Daneben!")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Treffer!")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Treffer!")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Treffer!")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Treffer!")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Versenkt!")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Versenkt!")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Versenkt!")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Ha, ha, ha... ich habe gewonnen!")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Gut!")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("Wollen wir noch eins versuchen?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("Das hast du schon versucht!")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("Das hast du schon gesagt!")


dialogId("b2-nemuze", "font_cyan", "It can`t be a miss on this space.")
dialogStr("Auf dem Feld kann es nicht daneben gehen!")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Du schummelst!!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss`!")
dialogStr("Das habe ich versucht - und du hast \"Daneben\" gesagt!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/gods/dialogs_de.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Ich habe die Vermutung, dass wir gerade etwas Schreckliches entdecken.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Ich hab’s immer gewusst: Die Götter müssen verrückt sein.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Gott ist verrückt und die ganze Welt ist sein Spielzeug.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Ich denke, du hast Recht.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Ich fürchte, du hast Recht.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Ja, es ist schockierend.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("Was können wir dagegen tun?")


dialogId("lod-v-internovat", "font_big", "We can’t leave it this way. We must incarcerate them.")
dialogStr("Wir können es nicht so lassen. Wir müssen sie einlochen.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Was müssen wir?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Sie ins Irren... ich meine in die Haftanstalt der FDTO stecken.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Du hast Recht. Sollen wir beide nehmen?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Natürlich. Wenn wir einen hierlassen, fällt ihm vielleicht eine verrückte Idee ein. Er könnte zum Beispiel anfangen, Golf zu spielen.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Wohl kaum mit diesem Schläger. Ich denke, wir werden froh sein, wenn wir einen rausbekommen. Der andere wird dann harmlos sein.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Gut. Und welchen?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("Den Gelben.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("Den Blauen.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Diesen Gelben.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Diesen Blauen.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Das überlassen wir dem Spieler.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Das sollten wir dem Spieler überlassen.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Schau dir den Schläger an: etwas schreckliches ist mit ihm passiert.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Ein rosa Monster hat wahrscheinlich an ihm gesaugt.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Mutter hatte Recht. Krankhafter Spieltrieb ist die Wurzel allen Übels.")


dialogId("lod-m-palka", "font_small", "That’s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("Das ist wahr. Es wäre viel leichter, wenn der Tischtennisschläger irgendwo anders wäre.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Hast du übrigens bemerkt, dass der echte Golfball in der Ecke oben links und das Ding in der Ecke unten rechts der Kricktball ist?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Ist das ein verstecktes Zeichen?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Wer weiß.")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Ich habe gedacht, da oben ist ein Tennisball.")


dialogId("lod-v-rozliseni", "font_big", "It’s hard to say with this screen resolution.")
dialogStr("Schwierig zu sagen, bei dieser Bildschirmauflösung.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Diesmal ist unser Ziel, einen der Götter herauszubekommen.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Daneben!")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Daneben!")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Daneben!")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Daneben!")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Daneben!")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("Treffer!")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("Treffer!")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("Treffer!")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("Treffer!")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Versenkt!")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Versenkt!")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Versenkt!")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("Ich habe gewonnen, du Muttersöhnchen")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Ich fange an!")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Gut!")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Wollen wir noch eins spielen?")


dialogId("b1-nepodvadim", "font_yellow", "I don’t cheat.")
dialogStr("Ich schummle nicht!")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("Es war wahrscheinlich ein Fehler...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Daneben!")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Daneben!")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Daneben!")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Daneben!")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Daneben!")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Treffer!")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Treffer!")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Treffer!")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Treffer!")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Versenkt!")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Versenkt!")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Versenkt!")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Ha, ha, ha... ich habe gewonnen!")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Gut!")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("Wollen wir noch eins versuchen?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("Das hast du schon versucht!")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("Das hast du schon gesagt!")


dialogId("b2-nemuze", "font_cyan", "It can’t be a miss on this space.")
dialogStr("Auf dem Feld kann es nicht daneben gehen!")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Du schummelst!!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss’!")
dialogStr("Das habe ich versucht - und du hast \"Daneben\" gesagt!")
